﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Telerik.Windows.Data;
using Telerik.Windows.Controls;
using System.Data;
using Telerik.Windows.Controls.GridView;

namespace SingleGroupFooter
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();

            var style = new Style();
            style.Setters.Add(new Setter(GroupHeaderRow.ShowGroupHeaderColumnAggregatesProperty, false));
            style.Setters.Add(new Setter(GroupHeaderRow.ShowHeaderAggregatesProperty, false));
            var radGrid = new RadGridView { GroupRenderMode = GroupRenderMode.Flat, GroupRowStyle = style };
            Content = radGrid;

            // Table schema
            var data = new DataTable();
            var dbUser = data.Columns.Add("User");
            var dbType = data.Columns.Add("Type");
            var dbCategory = data.Columns.Add("Category");
            var dbAmt = data.Columns.Add("Amount", typeof(decimal));

            // Populate values
            var categories = new[] { "Cat A", "Cat B", "Cat C" };
            var types = new[] { "Trial", "Full" };
            for (var i = 0; i < 20; i++)
            {
                data.Rows.Add(
                    "User " + i,
                    types[i % types.Length],
                    categories[i % categories.Length],
                    i * 100d);
            }

            // Prepare RadGridView
            radGrid.ItemsSource = data;
            radGrid.AutoExpandGroups = true;
            radGrid.ShowColumnFooters = true;
            radGrid.AutoGenerateColumns = false;

            // Build RadGrid columns
            var gridColumns = new[] { dbUser, dbType, dbCategory, dbAmt }
                .Select(dataColumn => new GridViewDataColumn
                {
                    UniqueName = dataColumn.ColumnName,
                    DataMemberBinding = new Binding(dataColumn.ColumnName),
                })
                .ToList();
            radGrid.Columns.AddRange(gridColumns);

            // Sum Amount
            var amtCol = gridColumns.Last();
            var amtFormat = "{0:C}";
            amtCol.DataFormatString = amtFormat;
            amtCol.AggregateFunctions.Add(new SumFunction()
            {
                SourceField = dbAmt.ColumnName,
                SourceFieldType = dbAmt.DataType,
                ResultFormatString = amtFormat
            });
            radGrid.ShowGroupFooters = true;

            // Show grand total label
            radGrid.Columns[0].Footer = "Grand Total";

            // Nested grouping
            var groupColumns = new[] {
                dbCategory,
                dbType
            };

            foreach (var group in groupColumns)
            {
                var colGroup = new GroupDescriptor { Member = group.ColumnName  };
                radGrid.GroupDescriptors.Add(colGroup);
            }

            var firstColumn = gridColumns.First();
            firstColumn.GroupFooterTemplateSelector = new MyGroupFooterTemplateSelector();
        }

        private void Button1_Click(object sender, RoutedEventArgs e)
        {

        }

        private void Button2_Click(object sender, RoutedEventArgs e)
        {

        }
    }
}
